class Products(object):

    def __init__(self, client):
        self.client = client

    def list_matching_products(self, query, query_context_id):
        """
        Returns a list of products and their attributes, based on a
        search query.

        Learn more: http://docs.developer.amazonservices.com/en_US/products/Products_ListMatchingProducts.html
        """  # noqa: E501
        pass
